package com.example.doublescreen;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.graphics.Point;
import android.hardware.display.DisplayManager;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.util.Log;
import android.view.Display;
import android.view.View;
import android.view.WindowManager;

import androidx.annotation.RequiresApi;
import androidx.appcompat.app.AppCompatActivity;

public class MainActivity extends AppCompatActivity {

    private static final String TAG = "MainActivity";
    DifferentDisplay mPresentation;
    BSImageDisplay mBSPresentation;
    //双屏显示
    DisplayManager mDisplayManager;//屏幕管理类
    Display[] displays;//屏幕数组

    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR1)
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        GetPermission();

        mDisplayManager = (DisplayManager) MainActivity.this.getSystemService(Context.DISPLAY_SERVICE);
        displays = mDisplayManager.getDisplays(); //得到显示器数组
        Log.i(TAG, "multiScreenDisplay: displays count = " + displays.length);

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
            multiScreenDisplay();
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR1)
    void multiScreenDisplay() {
        if (displays.length > 1) {
            mPresentation = new DifferentDisplay
                    (getApplicationContext(), displays[1]);//displays[1]是副屏
            mPresentation.getWindow().setType(WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY);
//            if you use apiLevel >= 19, don't use
//            WindowManager.LayoutParams.type = WindowManager.LayoutParams.TYPE_SYSTEM_ALERT
//            which gets the following error:
//            android.view.WindowManager$BadTokenException: Unable to add window android.view.ViewRootImpl$W@40ec8528 -- permission denied for this window type
//            Use this instead:
//            LayoutParams.TYPE_TOAST or TYPE_APPLICATION_PANEL
            mPresentation.show();
        }
    }

    void GetPermission() {
        if (Build.VERSION.SDK_INT >= 23) {
            if (!Settings.canDrawOverlays(this)) {
                Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION,
                        Uri.parse("package:" + getPackageName()));
                startActivityForResult(intent, 1234);
            }
        } else {
            Intent intent = new Intent(this, Service.class);
            startService(intent);
        }

    }

    @Override
    protected void onStop() {
        super.onStop();
        if (mPresentation != null) {
            mPresentation.dismiss();
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        if (mPresentation != null) {
            mPresentation.show();
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mPresentation != null) {
            mPresentation.dismiss();
        }
    }

    public void showBS(View view) {
        if (mPresentation != null) {
            mPresentation.show();
        }
    }

    public void dismissBS(View view) {
        if (mPresentation != null) {
            mPresentation.dismiss();
        }
    }

    public void destroyBS(View view) {
        if (mPresentation != null) {
            mPresentation.dismiss();
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR1)
    public void showBSImage(View view) {
        if (mPresentation != null) {
            mPresentation.dismiss();
        }

        if (displays.length > 1) {
            mBSPresentation = new BSImageDisplay
                    (getApplicationContext(), displays[1]);//displays[1]是副屏
            mBSPresentation.getWindow().setType(WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY);
            mBSPresentation.show();
            Point pt = new Point();
            displays[1].getSize(pt);
            Log.d("Main","size:"+pt.x+","+pt.y+"@"+displays[1].getRotation());
        }
    }

    public void dismissBSImage(View view) {
        if (mBSPresentation != null) {
            mBSPresentation.dismiss();
        }
    }

    @RequiresApi(api = Build.VERSION_CODES.JELLY_BEAN_MR1)
    public void changeBSImage(View view) {
        if (mBSPresentation == null) {
            if (displays.length > 1) {
                mBSPresentation = new BSImageDisplay
                        (getApplicationContext(), displays[1]);//displays[1]是副屏
                mBSPresentation.getWindow().setType(WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY);
                mBSPresentation.show();
            }
        }
        if (mBSPresentation != null) {
            mBSPresentation.show();
            mBSPresentation.setBSImage(getResources().getDrawable(R.drawable.big_screen_nice_image));
        }
    }
}




























